# Hermitian Spectral Clustering

A Python implementation of the CLSZ algorithm for clustering directed graphs.

## Reference

The primary reference for this algorithm is 

```Cucuringu, M., Li, H., Sun, H. and Zanetti, L., 2020, June. Hermitian matrices for clustering directed graphs: insights and applications. In International Conference on Artificial Intelligence and Statistics (pp. 983-992). PMLR.```

## Implementation

This repository conatins a straightforward python implementation of the algorithm. It is intended mainly as example code to encourage experimentation and extension.
